import static java.lang.Continuation.*;

public class Sample {  
  public static void doWork(ContinuationScope scope) {
    System.out.println("entering....");
    
    yield(scope);
    System.out.println("step 1");
    yield(scope);

    System.out.println("step 2");
    yield(scope);

    System.out.println("step 3");
  }
  
  public static void main(String[] args) {
    System.out.println("Starting...");
    
    var scope = new ContinuationScope("scope");
    var continuation = new Continuation(scope, () -> doWork(scope));
    
    while(!continuation.isDone()) {
      System.out.println("In the loop");
      continuation.run();
    }
    
    var fiber = Fiber.schedule(
      () -> System.out.println("runnning in " + Thread.currentThread()));
      
    fiber.join();
    
    //Fibers are super lightweight thread.
    //While the task may block the underlying thread does not block
    //This give a better scale. We can have only 1000 of thread in a JVM, but
    //millions of Fibers in it.
  }
}




